# T-Rex: Terminal Redis Explorer

## Getting Started

### Installation:

```bash
pip install -r requirements.txt
```

### Running

```
python main.py
```

`C-d` will quit.
`Shift` key will change focus to the different windows.
